Documentation
¶
Overview ¶
Package errtype provides a number of concrete types which are used by the cloudsqlconn package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConfigError ¶
type ConfigError struct {
// contains filtered or unexported fields
}
ConfigError represents an incorrect request by the user. Config errors usually indicate a semantic error (e.g., the instance connection name is malformed, the SQL instance does not support the requested IP type, etc.) ConfigError's should not be retried.
func NewConfigError ¶
func NewConfigError(msg, cn string) *ConfigError
NewConfigError initializes a ConfigError.
type DialError ¶
type DialError struct {
// Err is the underlying error and may be nil.
Err error
// contains filtered or unexported fields
}
DialError represents a problem that occurred when trying to dial a SQL instance (e.g., a failure to set the keep-alive property, a TLS handshake failure, a missing certificate, etc.). DialError's are often network-related and can be retried.
func NewDialError ¶
NewDialError initializes a DialError.
type RefreshError ¶
type RefreshError struct {
// Err is the underlying error and may be nil.
Err error
// contains filtered or unexported fields
}
RefreshError means that an error occurred during the background refresh operation. In general, this is an unexpected error caused by an interaction with the API itself (e.g., missing certificates, invalid certificate encoding, region mismatch with the requested instance connection name, etc.). RefreshError's usually can be retried.
func NewRefreshError ¶
func NewRefreshError(msg, cn string, err error) *RefreshError
NewRefreshError initializes a RefreshError.
func (*RefreshError) Error ¶
func (e *RefreshError) Error() string
func (*RefreshError) Unwrap ¶
func (e *RefreshError) Unwrap() error
type ResourceExhaustedError ¶ added in v1.24.0
type ResourceExhaustedError struct {
Err error
// contains filtered or unexported fields
}
ResourceExhaustedError represents a temporary failure because the service is busy.
func NewResourceExhaustedError ¶ added in v1.24.0
func NewResourceExhaustedError(msg, cn string, err error) *ResourceExhaustedError
NewResourceExhaustedError initializes a ResourceExhaustedError.
func (*ResourceExhaustedError) Error ¶ added in v1.24.0
func (e *ResourceExhaustedError) Error() string
func (*ResourceExhaustedError) Unwrap ¶ added in v1.24.0
func (e *ResourceExhaustedError) Unwrap() error