Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsInstanceDNSName ¶ added in v1.24.0
IsInstanceDNSName returns true if the domain name matches the well-known Cloud SQL instance DNS name pattern.
func IsValidDomain ¶ added in v1.16.0
IsValidDomain validates that a string is a well-formed domain name
func ParseInstanceDNSName ¶ added in v1.24.0
func ParseInstanceDNSName(dnsName string) (instanceLabel, projectLabel, region, suffix string, ok bool)
ParseInstanceDNSName parses a DNS name into its constituent parts. Instance DNS names follow this template: {instance-dns-label}.{project-dns-label}.{cloud-region}.{dns-suffix} Suffix is one of: sql.goog, sql-psa.goog, sql-psc.goog (with optional trailing dot). This returns ok == false when the region is "global"
Types ¶
type ConnName ¶
type ConnName struct {
// contains filtered or unexported fields
}
ConnName represents the "instance connection name", in the format "project:region:name".
func ParseConnName ¶
ParseConnName initializes a new ConnName struct.
func ParseConnNameWithDomainName ¶ added in v1.13.0
ParseConnNameWithDomainName initializes a new ConnName struct, also setting the domain name.
func (*ConnName) DomainName ¶ added in v1.13.0
DomainName returns the domain name for this instance
func (*ConnName) HasDomainName ¶ added in v1.13.0
HasDomainName returns whether the Cloud SQL instance has a domain name
type ConnectionNameResolver ¶ added in v1.12.0
type ConnectionNameResolver interface {
// Resolve accepts a name, and returns a ConnName with the instance
// connection string for the name. If the name cannot be resolved, returns
// an error.
Resolve(ctx context.Context, name string) (ConnName, error)
}
ConnectionNameResolver resolves the connection name string into a valid instance name. This allows an application to replace the default resolver with a custom implementation.